import React, { CSSProperties, ReactElement, ReactNode } from "react";
export type TListHeadCellProps = {
    wrapperClassName?: string;
    wrapperStyle?: CSSProperties;
    className?: string;
    entity?: Record<string, any>;
    style?: CSSProperties;
    content: ReactNode | ((cellProps?: any) => ReactNode);
    alignment?: "center" | "right" | "left";
};
export declare const renderTitleCell: (props: TListHeadCellProps) => (cellProps?: Record<string, any>) => React.JSX.Element;
export type TListBodyCellProps = {
    wrapperClassName?: string;
    wrapperStyle?: CSSProperties;
    className?: string;
    entity?: Record<string, any>;
    style?: CSSProperties;
    rowSelected?: boolean;
    content: ReactNode | ((v?: any, record?: Record<string, any>, entity?: Record<string, any>) => ReactNode);
    alignment?: "center" | "right" | "left";
    isFirstColumn?: boolean;
};
export declare const renderBodyCell: (props: TListBodyCellProps) => (v?: any, record?: Record<string, any>) => React.JSX.Element;
export type TListColumnTooltip = {
    placement?: "top" | "left" | "bottom" | "right";
    title: any;
    color?: string;
};
export type TListColumnMenuItem = {
    title: string;
    action: string;
    confirmation?: string;
};
export type TToUpdateRecordSettings = {
    partial?: boolean;
    skipUpdateRecordAfterSave?: boolean;
    onSuccess?: (newRecord?: Record<string, any>) => Record<string, any> | undefined;
    onError?: (error: any) => void;
};
export type TListColumnSettings = {
    getCurrentRecord?: () => Record<string, any> | undefined;
    onRenderWrapperClassName?: (record?: Record<string, any>) => string;
    onRenderWrapperStyle?: (record?: Record<string, any>) => Record<string, any>;
    onRenderCellClassName?: (record?: Record<string, any>) => string;
    onRenderCellStyle?: (record?: Record<string, any>) => Record<string, any>;
    onRenderIconClassName?: (record?: Record<string, any>) => string;
    onRenderIconColor?: (record?: Record<string, any>) => string;
    onGetIconUrl?: (record?: Record<string, any>) => string | undefined;
    onGetText?: (record?: Record<string, any>) => string | undefined;
    onGetControlId?: (record?: Record<string, any>) => string | undefined;
    onGetTooltip?: (record?: Record<string, any>) => TListColumnTooltip | undefined;
    onGetActionName?: (record?: Record<string, any>) => string;
    onValidMenuItem?: (menuItem: TListColumnMenuItem, record?: Record<string, any>) => boolean;
    className?: string;
    menuItems?: TListColumnMenuItem[];
    recordInAction?: TListRecordInAction;
    context?: Record<string, any>;
    title?: any;
    tooltip?: TListColumnTooltip;
    onClickTag?: (tag: string) => void;
    onClick?: TListColumnOnClick;
    toApplyConditions?: (conditions: Record<string, any>[]) => void;
    toUpdateRecord?: (record: Record<string, any>, save: boolean, settings?: TToUpdateRecordSettings) => Promise<Record<string, any> | undefined>;
    actionName?: string;
    showTags?: boolean;
    colorName?: string;
    fixed?: "right" | "left";
    width?: number;
    text?: string;
    controlId?: string;
    ui?: Record<string, any>;
    onRenderTextClassName?: (record?: Record<string, any>) => string;
    onRenderTextStyle?: (record?: Record<string, any>) => CSSProperties;
    renderTopContent?: (record: Record<string, any>, entity?: Record<string, any>, settings?: TListColumnSettings) => any;
    renderMainContent?: (record: Record<string, any>, entity?: Record<string, any>, settings?: TListColumnSettings) => any;
    renderBottomContent?: (record: Record<string, any>, entity?: Record<string, any>, settings?: TListColumnSettings) => any;
};
export type TListRecordInAction = {
    doing: boolean;
    record: Record<string, any>;
    actionName: string;
    actionMessage?: string;
    color?: string;
};
export type TListColumn = {
    title: ReactNode | ((props?: any) => ReactNode);
    id: string;
    dataIndex: string;
    key: string;
    width?: number;
    fixed?: "right" | "left";
    className?: string;
    recordInAction?: TListRecordInAction;
    render: (id: string, record: Record<string, any>, rowIndex: number) => ReactElement;
};
export type TListConfirmationType = "default" | "primary" | "ghost" | "dashed" | "link" | "text" | "danger";
export type TListActionMenuItem = {
    title: string;
    action: string;
    confirmationTitle?: string;
    confirmationType?: TListConfirmationType;
};
export type TListColumnOnClick = (record: Record<string, any>, action?: string, entity?: Record<string, any>, rowIndex?: number) => void;
export declare const getDefaultFirstBodyCell: (onClickRecord: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings) => {
    title: any;
    dataIndex: string;
    id: string;
    key: string;
    className: string;
    render: (v?: any, record?: Record<string, any>) => React.JSX.Element;
};
export declare const renderListActionButtonColumn: (menuItems: TListActionMenuItem[], onClick?: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings) => TListColumn;
export declare const renderListIconButtonColumn: (iconUrl?: string, action?: string, onClick?: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings) => TListColumn;
export declare const DEFAULT_LIST_SELECT_COLUMN: (onClick?: ((record: Record<string, any>, action?: string, entity?: Record<string, any>, rowIndex?: number) => void) | undefined, entity?: Record<string, any>, settings?: TListColumnSettings) => TListColumn;
export declare const DEFAULT_LIST_PLAY_COLUMN: (onClick: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings) => TListColumn;
export declare const DEFAULT_LIST_EDIT_COLUMN: (onClick: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings) => TListColumn;
export declare const DEFAULT_LIST_OPEN_IN_BROWSER_COLUMN: (onClick: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings) => TListColumn;
export declare const DEFAULT_LIST_EMAIL_COLUMN: (onClick: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings) => TListColumn;
export declare const DEFAULT_LIST_ACTION_COLUMN: (onClick?: TListColumnOnClick, entity?: Record<string, any>, settings?: ({
    menuItems?: {
        title: string;
        action: string;
        confirmation?: string | undefined;
    }[] | undefined;
} & TListColumnSettings) | undefined) => TListColumn;
export declare const renderListDefaultColumn: (record: Record<string, any>, entity?: Record<string, any>, settings?: TListColumnSettings) => React.JSX.Element | null;
export declare const renderListRecordInAction: (record: Record<string, any>, entity?: Record<string, any>, settings?: TListColumnSettings) => React.JSX.Element | null;
export declare const DEFAULT_LIST_COLUMNS: (onClickRecord: TListColumnOnClick, entity?: Record<string, any>, settings?: TListColumnSettings, columnSettings?: Record<string, TListColumnSettings & Record<string, any>>) => TListColumn[];
