//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React, { Fragment, useEffect, useState } from "react";
import { isArray, isNil } from "lodash";
import Logo from "primeobjects-ui-web-basic/build/cjs/controls/logo";
import SVG from "primeobjects-ui-web-basic/build/cjs/controls/svg";
import { Popover, Transition } from "@headlessui/react";
import { isNonEmptyString, isObject, getWindow } from "primeobjects-helper-util";
import { HeadMenuDesktopView } from "primeobjects-ui-web-basic/build/cjs/controls/header/menu-desktop";
import { HeadMenuMobileView } from "primeobjects-ui-web-basic/build/cjs/controls/header/menu-mobile";
import RedirectButton from "primeobjects-ui-web-basic/build/cjs/controls/redirect-button";
import { usePrimaryColor } from "primeobjects-helper-ui/build/cjs/hooks/primary-color";
import { getCurrentPoolUser } from "../context/auth-cognito";
export var SiteNavigation = function (props) {
    var navigation = props.navigation, solution = props.solution;
    var style = isObject(props.style) ? props.style : {};
    var _a = useState(false), hasUserSession = _a[0], setHasUserSession = _a[1];
    var className = isNonEmptyString(props.className) ? props.className : "";
    var primaryColor = usePrimaryColor(solution);
    var site = solution.site;
    var siteName = props.siteName
        ? props.siteName
        : (site === null || site === void 0 ? void 0 : site.name)
            ? site === null || site === void 0 ? void 0 : site.name
            : "";
    var siteLogo = props.siteLogo
        ? props.siteLogo
        : (site === null || site === void 0 ? void 0 : site.logo)
            ? site === null || site === void 0 ? void 0 : site.logo
            : "/logo.svg";
    useEffect(function () {
        getCurrentPoolUser(solution).then(function (r) {
            setHasUserSession(!isNil(r));
        });
    }, [solution === null || solution === void 0 ? void 0 : solution.id]);
    var onClickLogo = function () {
        if (props.onClickLogo) {
            return props.onClickLogo();
        }
        else {
            getWindow().location.replace("/");
        }
    };
    return (React.createElement(Popover, null,
        React.createElement("div", { className: "relative flex flex-row ".concat(className), style: style },
            React.createElement("nav", { className: "relative flex flex-row w-full items-center justify-between sm:h-10 lg:justify-start", "aria-label": "Global" },
                React.createElement(Logo, { id: "nav-logo", onClick: onClickLogo, logoSrc: siteLogo, logoSize: 30, text: siteName, color: primaryColor["600"] }),
                React.createElement("div", { className: "hidden md:flex space-x-8 pl-8" }, isArray(navigation) && navigation.length > 0 && (React.createElement(HeadMenuDesktopView, { navigation: navigation, color: primaryColor }))),
                isArray(navigation) && navigation.length > 0 && (React.createElement("div", { className: "flex items-center flex-grow flex-shrink-0 lg:flex-grow-0" },
                    React.createElement("div", { className: "flex items-center justify-end w-full md:w-auto " },
                        React.createElement("div", { className: "-mr-2 flex items-center md:hidden" },
                            React.createElement(Popover.Button, { className: "bg-white rounded-md p-2 inline-flex items-center  border justify-center text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none" },
                                React.createElement("span", { className: "sr-only" }, "Open main menu"),
                                React.createElement(SVG, { id: "nav-menu", src: "/icons/platform/menu.svg", size: 30 }))))))),
            hasUserSession && (React.createElement(RedirectButton, { color: primaryColor[400], targetUrl: "/list/dashboard", className: "max-w-28 min-w-28 min-h-10 rounded-md flex flex-col items-center cursor-pointer border p-2 bg-gray-50 font-base text-sm hover:shadow justify-center" }, "Dashboard"))),
        React.createElement(Transition, { as: Fragment, enter: "duration-150 ease-out", enterFrom: "opacity-0 scale-95", enterTo: "opacity-100 scale-100", leave: "duration-100 ease-in", leaveFrom: "opacity-100 scale-100", leaveTo: "opacity-0 scale-95" },
            React.createElement(Popover.Panel, { className: "fixed bg-white z-10 top-0 left-0 inset-x-0 p-2 transition transform origin-top-right md:hidden h-full " },
                React.createElement("div", { className: "rounded-lg shadow-md bg-white ring-1 ring-black ring-opacity-5 h-full overflow-hidden" },
                    React.createElement("div", { className: "px-5 py-3 flex items-center justify-between h-18 border-b" },
                        React.createElement(Logo, { id: "nav-pop-lego", color: primaryColor["600"], onClick: onClickLogo, logoSrc: siteLogo, logoSize: 30, text: siteName, textStyle: { color: primaryColor["600"] } }),
                        React.createElement("div", { className: "-mr-2" },
                            React.createElement(Popover.Button, { className: "bg-white rounded-md p-2 inline-flex items-center justify-center text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none" },
                                React.createElement("span", { className: "sr-only" }, "Close main menu"),
                                React.createElement(SVG, { id: "nav-pop-close", src: "/icons/platform/close.svg", size: 30 })))),
                    React.createElement("div", { className: "px-2 pt-2 pb-3 space-y-1 overflow-hidden overflow-y-auto", style: { height: "calc(100% - 66px)" } },
                        React.createElement(Popover.Group, { as: "nav", className: "space-x-10" }, isArray(navigation) &&
                            navigation.length > 0 && (React.createElement(HeadMenuMobileView, { navigation: navigation })))))))));
};
export default SiteNavigation;
//# sourceMappingURL=site-navigation.js.map